Struct ExportData
Source pub struct ExportData {
pub nodes: Vec<Variable>,
pub edges: Vec<ExportEdge>,
pub events: Vec<Event>,
pub metadata: ExportMetadata,
}
Complete export format optimized for visualization tools.
Create export data from graph and events.
Formats the value using the given formatter.
Read more
Serialize this value into the given Serde serializer.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.